==> Zenroom-2.0.0.tar.gz: Zenroom-2.0.0/docs/_sidebar.md <==

- Zenroom basics
  - [Getting Started](/)
  - [Zenroom's VM and Zencode](/pages/zencode-intro.md "Zencode cookbook intro")  
  - [Zenroom's Command Line Interface](/pages/how-to-exec.md "Execute")


- Zencode Basics
  - [Quickstart](/pages/zencode-cookbook-intro.md "Zencode Quickstart") 
  - [Zencode: "Given" phase](/pages/zencode-cookbook-given.md "Zencode cookbook Given")
  - [Zencode: "When phase](/pages/zencode-cookbook-when.md "Zencode cookbook When")
  - [Zencode: "Then" phase](/pages/zencode-cookbook-then.md "Zencode cookbook Then")
  - [Zencode: "If/Endif" branching](/pages/zencode-if-endif.md "Zencode branching")

- Zencode Advanced 
  - [Cryptography](/pages/zencode-crypto.md "Zencode")
  - [Scenario 'credentials': zero knowledge proof and attribute based credentials](/pages/zencode-scenario-credentials.md "Zencode credentials")
  - [Scenario 'ecdh': encryption, signature](/pages/zencode-scenarios-ecdh "Zencode ecdh")
  - [Scenario 'petition': cryptographic petition](/pages/zencode-scenarios-petition "Zencode petition")
  - [Scenario 'dp3t': proximity tracing](/pages/zencode-scenario-dp3t "Zencode petition")
  - [Scenario 'secshare': secret sharing](/pages/zencode-scenario-secShare "Zencode secret share")
  - [Scenario 'w3c': Verifiable Credentials](/pages/zencode-cookbook-w3c-vc "W3C Verifiable Credentials")
  - [Scenario 'Reflow': Multisignature](/pages/zencode-scenario-reflow "Reflow Multisignature")
  - [Scenario 'http': Create GET requests](/pages/zencode-scenarios-http.md "create GET requests")
 <!--- --->
  - [Scenario 'bitcoin': Create bitcoin transactions](/pages/zencode-scenarios-bitcoin.md "Create bitcoin transactions")  
  - [Zencode "rules"](/pages/zencode-rules.md "Zencode encoding and format rules")
  - [Zencode "config"](/pages/zenroom-config.md "Zenroom config")
  - [Zencode command list](/pages/zencode-list.md "Zencode command list")  

- Bindings
  - [ Use Zenroom as a library](/pages/how-to-embed.md "Embed") 
  - [JavaScript ](/pages/javascript.md "Use Zenroom in JavaScript")
  - [Python](/pages/python.md "Use Zenroom in JavaScript")
  - [Java](/pages/java.md "Use Zenroom in Java")
  - [iOS](/pages/ios.md "Use Zenroom in iOS")

- Integration
 - [Zenroom in node.js](/pages/zenroom-javascript1b.md "Use Zenroom in node.js")
 - [Zenroom in the browser](/pages/zenroom-javascript2b.md "Use Zenroom in the browser")
 - [Zenroom in React](/pages/zenroom-javascript3.md "Use Zenroom in React")
 - [Zenroom in React Native](/pages/zenroom-react-native.md "Use Zenroom in React Native")
 - [Zenroom ClojureScript](/pages/zenroom-clojurescript.md "Zenroom ClojureScript]") 

- Extensions
 - [RESTroom-mw](/pages/restroom-mw)
 - [Redroom](/ext/redroom)
 - [Lotionroom](/ext/lotionroom)
 - [Sawroom](/ext/sawroom)
 - [Apiroom](/pages/apiroom)


- Build & Test
 - [Build instructions](/pages/how-to-build.md "Build Zenroom")  
 - [Zenroom on Cortex M](/pages/cortex.md "Zenroom on Cortex M")
 - [Random quality](/pages/random.md "Random quality measurement")
 - [Browser-encryption demo](/pages/encrypt.md "Browser-encryption demo")
 - [Telegram bot](/pages/zenroomTelegramBotPython.md "Zenroom Telegram bot")



- Programming Lua
  - [Lua](/pages/lua.md "in Lua")
  - [Lua full reference](/pages/ldoc/o/README.md "in Lua") 
 
- Misc
 - [Changelog](CHANGELOG)
 - [Contributing](CONTRIBUTING)
 - [To-do](TODO)
 - [📄 Zenroom whitepaper](/pages/zenroom_whitepaper.pdf ':ignore')

<!--- comment example --->

==> Zenroom-3.23.4.tar.gz: Zenroom-3.23.4/docs/_sidebar.md <==

- Zenroom basics
  - [Getting Started](/)
  - [Zenroom's VM and Zencode](/pages/zencode-intro.md "Zencode cookbook intro")
  - [Zenroom's Command Line Interface](/pages/how-to-exec.md "Execute")


- Zencode Basics
  - [Quickstart](/pages/zencode-cookbook-intro.md "Zencode Quickstart") 
  - [Zencode: "Given" phase](/pages/zencode-cookbook-given.md "Zencode cookbook Given")
  - [Zencode: "When phase](/pages/zencode-cookbook-when.md "Zencode cookbook When")
  - [Zencode: "Then" phase](/pages/zencode-cookbook-then.md "Zencode cookbook Then")
  - [Zencode: "If/Endif" branching](/pages/zencode-if-endif.md "Zencode branching")
  - [Zencode: debug](/pages/zencode-debug.md "Zencode debug")

- Zencode Advanced 
  - [Cryptography](/pages/zencode-crypto.md "Zencode")
  - [Scenario 'credentials': zero knowledge proof and attribute based credentials](/pages/zencode-scenario-credentials.md "Zencode credentials")
  - [Scenario 'ecdh': encryption, signature](/pages/zencode-scenarios-ecdh "Zencode ecdh")
  - [Scenario 'eddsa': signature](/pages/zencode-scenarios-eddsa "Zencode eddsa")
  - [Scenario 'bbs': signature, zero knowledge proof](/pages/zencode-scenarios-bbs "Zencode BBS")
  - [Scenario 'petition': cryptographic petition](/pages/zencode-scenarios-petition "Zencode petition")
  - [Scenario 'dp3t': proximity tracing](/pages/zencode-scenario-dp3t "Zencode dp3t")
  - [Scenario 'secshare': secret sharing](/pages/zencode-scenario-secShare "Zencode secret share")
  - [Scenario 'pvss': publicly verifiable secret sharing](/pages/zencode-scenario-pvss.md "Zencode pvss")
  - [Scenario 'w3c': Verifiable Credentials](/pages/zencode-cookbook-w3c-vc "W3C Verifiable Credentials")
  - [Scenario 'Reflow': Multisignature](/pages/zencode-scenario-reflow "Reflow Multisignature")
  - [Scenario 'http': Create GET requests](/pages/zencode-scenarios-http.md "create GET requests")
  - [Scenario 'schnorr': Signature](/pages/zencode-scenarios-schnorr.md "Zencode schnorr")
  - [Scenario 'qp': KEM, signature](/pages/zencode-scenarios-qp.md "Zencode qp")
 <!--- --->
  - [Scenario 'bitcoin': Create bitcoin transactions](/pages/zencode-scenarios-bitcoin.md "Create bitcoin transactions")
  - [Scenario 'ethereum': Create ethereum transactions](/pages/zencode-scenarios-ethereum.md "Create ethereum transactions")
  - [Zencode "rules"](/pages/zencode-rules.md "Zencode encoding and format rules")
  - [Zencode "config"](/pages/zenroom-config.md "Zenroom config")
  - [Zencode command list](/pages/zencode-list.md "Zencode command list")

- Bindings
  - [ Use Zenroom as a library](/pages/how-to-embed.md "Embed") 
  - [JavaScript ](/pages/javascript.md "Use Zenroom in JavaScript")
  - [Python](/pages/python.md "Use Zenroom in JavaScript")
  - [Java](/pages/java.md "Use Zenroom in Java")
  - [iOS](/pages/ios.md "Use Zenroom in iOS")

- Integration
 - [Zenroom in node.js](/pages/zenroom-javascript1b.md "Use Zenroom in node.js")
 - [Zenroom in the browser](/pages/zenroom-javascript2b.md "Use Zenroom in the browser")
 - [Zenroom in React](/pages/zenroom-javascript3.md "Use Zenroom in React")
 - [Zenroom in React Native](/pages/zenroom-react-native.md "Use Zenroom in React Native")
 - [Zenroom ClojureScript](/pages/zenroom-clojurescript.md "Zenroom ClojureScript]") 

- Extensions
 - [RESTroom-mw](/pages/restroom-mw)
 - [Redroom](/ext/redroom)
 - [Lotionroom](/ext/lotionroom)
 - [Sawroom](/ext/sawroom)
 - [Apiroom](/pages/apiroom)


- Build & Test
 - [Build instructions](/pages/how-to-build.md "Build Zenroom")  
 - [Zenroom on Cortex M](/pages/cortex.md "Zenroom on Cortex M")
 - [Random quality](/pages/random.md "Random quality measurement")
 - [Browser-encryption demo](/pages/encrypt.md "Browser-encryption demo")
 - [Telegram bot](/pages/zenroomTelegramBotPython.md "Zenroom Telegram bot")



- Programming Lua
  - [Lua](/pages/lua.md "in Lua")
  - [Lua full reference](/pages/ldoc/o/README.md "in Lua") 
 
- Misc
 - [Changelog](CHANGELOG)
 - [Contributing](CONTRIBUTING)
 - [To-do](TODO)
 - [📄 Zenroom whitepaper](/pages/zenroom_whitepaper.pdf ':ignore')

<!--- comment example --->
